@@ -161,7 +161,6 @@ CONFIGS_CHANGES = [
         old_default="SequentialExecutor",
         new_default="LocalExecutor",
         was_removed=False,
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("core", "hostname"),
@@ -379,24 +378,53 @@ CONFIGS_CHANGES = [
         config=ConfigParameter("webserver", "session_lifetime_minutes"),
         renamed_to=ConfigParameter("fab", "session_lifetime_minutes"),
     ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "access_denied_message"),
+        renamed_to=ConfigParameter("fab", "access_denied_message"),
+    ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "expose_hostname"),
+        renamed_to=ConfigParameter("fab", "expose_hostname"),
+    ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "navbar_color"),
+        renamed_to=ConfigParameter("fab", "navbar_color"),
+    ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "navbar_text_color"),
+        renamed_to=ConfigParameter("fab", "navbar_text_color"),
+    ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "navbar_hover_color"),
+        renamed_to=ConfigParameter("fab", "navbar_hover_color"),
+    ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "navbar_text_hover_color"),
+        renamed_to=ConfigParameter("fab", "navbar_text_hover_color"),
+    ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "x_frame_enabled"),
+        was_deprecated=False,
+    ),
     ConfigChange(
         config=ConfigParameter("webserver", "base_url"),
         renamed_to=ConfigParameter("api", "base_url"),
     ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "secret_key"),
+        renamed_to=ConfigParameter("api", "secret_key"),
+    ),
     ConfigChange(
         config=ConfigParameter("webserver", "web_server_host"),
         renamed_to=ConfigParameter("api", "host"),
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "web_server_port"),
         renamed_to=ConfigParameter("api", "port"),
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "workers"),
         renamed_to=ConfigParameter("api", "workers"),
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "web_server_worker_timeout"),
@@ -405,17 +433,18 @@ CONFIGS_CHANGES = [
     ConfigChange(
         config=ConfigParameter("webserver", "web_server_ssl_cert"),
         renamed_to=ConfigParameter("api", "ssl_cert"),
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "web_server_ssl_key"),
         renamed_to=ConfigParameter("api", "ssl_key"),
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "access_logfile"),
         renamed_to=ConfigParameter("api", "access_logfile"),
-        breaking=True,
+    ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "enable_swagger_ui"),
+        renamed_to=ConfigParameter("api", "enable_swagger_ui"),
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "error_logfile"),
@@ -467,27 +496,31 @@ CONFIGS_CHANGES = [
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "enable_proxy_fix"),
-        was_deprecated=False,
+        renamed_to=ConfigParameter("fab", "enable_proxy_fix"),
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "proxy_fix_x_for"),
-        was_deprecated=False,
+        renamed_to=ConfigParameter("fab", "proxy_fix_x_for"),
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "proxy_fix_x_proto"),
-        was_deprecated=False,
+        renamed_to=ConfigParameter("fab", "proxy_fix_x_proto"),
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "proxy_fix_x_host"),
-        was_deprecated=False,
+        renamed_to=ConfigParameter("fab", "proxy_fix_x_host"),
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "proxy_fix_x_port"),
-        was_deprecated=False,
+        renamed_to=ConfigParameter("fab", "proxy_fix_x_port"),
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "proxy_fix_x_prefix"),
-        was_deprecated=False,
+        renamed_to=ConfigParameter("fab", "proxy_fix_x_prefix"),
+    ),
+    ConfigChange(
+        config=ConfigParameter("webserver", "expose_config"),
+        renamed_to=ConfigParameter("api", "expose_config"),
     ),
     ConfigChange(
         config=ConfigParameter("webserver", "cookie_secure"),
@@ -569,7 +602,6 @@ CONFIGS_CHANGES = [
         "If your DAGs rely on catchup behavior, not explicitly defined in the DAG definition, "
         "set this configuration parameter to `True` in the `scheduler` section of your `airflow.cfg` "
         "to enable the behavior from Airflow 2.x.",
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("scheduler", "create_cron_data_intervals"),
@@ -577,7 +609,6 @@ CONFIGS_CHANGES = [
         old_default="True",
         new_default="False",
         was_removed=False,
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("scheduler", "create_delta_data_intervals"),
@@ -585,7 +616,6 @@ CONFIGS_CHANGES = [
         old_default="True",
         new_default="False",
         was_removed=False,
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("scheduler", "processor_poll_interval"),
@@ -665,7 +695,6 @@ CONFIGS_CHANGES = [
     ConfigChange(
         config=ConfigParameter("scheduler", "dag_dir_list_interval"),
         renamed_to=ConfigParameter("dag_processor", "refresh_interval"),
-        breaking=True,
     ),
     ConfigChange(
         config=ConfigParameter("scheduler", "local_task_job_heartbeat_sec"),
@@ -722,7 +751,6 @@ CONFIGS_CHANGES = [
     ConfigChange(
         config=ConfigParameter("triggerer", "default_capacity"),
         renamed_to=ConfigParameter("triggerer", "capacity"),
-        breaking=True,
     ),
     # email
     ConfigChange(
