@@ -416,6 +416,7 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self._auth_manager_class_name_set: set[str] = set()
         self._secrets_backend_class_name_set: set[str] = set()
         self._executor_class_name_set: set[str] = set()
+        self._queue_class_name_set: set[str] = set()
         self._provider_configs: dict[str, dict[str, Any]] = {}
         self._trigger_info_set: set[TriggerInfo] = set()
         self._notification_info_set: set[NotificationInfo] = set()
@@ -533,6 +534,12 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self.initialize_providers_list()
         self._discover_executors()
 
+    @provider_info_cache("queues")
+    def initialize_providers_queues(self):
+        """Lazy initialization of providers queue information."""
+        self.initialize_providers_list()
+        self._discover_queues()
+
     @provider_info_cache("notifications")
     def initialize_providers_notifications(self):
         """Lazy initialization of providers notifications information."""
@@ -1091,6 +1098,14 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
                     if _correctness_check(provider_package, executors_class_name, provider):
                         self._executor_class_name_set.add(executors_class_name)
 
+    def _discover_queues(self) -> None:
+        """Retrieve all queues defined in the providers."""
+        for provider_package, provider in self._provider_dict.items():
+            if provider.data.get("queues"):
+                for queue_class_name in provider.data["queues"]:
+                    if _correctness_check(provider_package, queue_class_name, provider):
+                        self._queue_class_name_set.add(queue_class_name)
+
     def _discover_config(self) -> None:
         """Retrieve all configs defined in the providers."""
         for provider_package, provider in self._provider_dict.items():
@@ -1221,6 +1236,11 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self.initialize_providers_executors()
         return sorted(self._executor_class_name_set)
 
+    @property
+    def queue_class_names(self) -> list[str]:
+        self.initialize_providers_queues()
+        return sorted(self._queue_class_name_set)
+
     @property
     def filesystem_module_names(self) -> list[str]:
         self.initialize_providers_filesystems()
@@ -1268,9 +1288,11 @@ class ProvidersManager(LoggingMixin, metaclass=Singleton):
         self._auth_manager_class_name_set.clear()
         self._secrets_backend_class_name_set.clear()
         self._executor_class_name_set.clear()
+        self._queue_class_name_set.clear()
         self._provider_configs.clear()
         self._trigger_info_set.clear()
         self._notification_info_set.clear()
         self._plugins_set.clear()
+
         self._initialized = False
         self._initialization_stack_trace = None
