@@ -162,7 +162,7 @@ class TestGetDags(TestDagEndpoint):
             ({"last_dag_run_state": "success", "exclude_stale": False}, 1, [DAG3_ID]),
             ({"last_dag_run_state": "failed", "exclude_stale": False}, 1, [DAG1_ID]),
             ({"dag_run_state": "failed"}, 1, [DAG1_ID]),
-            ({"dag_run_state": "failed", "exclude_stale": False}, 2, [DAG1_ID, DAG3_ID]),
+            ({"dag_run_state": "failed", "exclude_stale": False}, 1, [DAG1_ID]),
             (
                 {"dag_run_start_date_gte": DAG3_START_DATE_2.isoformat(), "exclude_stale": False},
                 1,
@@ -210,10 +210,10 @@ class TestGetDags(TestDagEndpoint):
                     "dag_run_state": "failed",
                     "exclude_stale": False,
                 },
-                1,
-                [DAG3_ID],
+                0,
+                [],
             ),
-            # # Sort
+            # Sort
             ({"order_by": "-dag_id"}, 2, [DAG2_ID, DAG1_ID]),
             ({"order_by": "-dag_display_name"}, 2, [DAG2_ID, DAG1_ID]),
             ({"order_by": "dag_display_name"}, 2, [DAG1_ID, DAG2_ID]),
@@ -356,9 +356,9 @@ class TestPatchDags(TestDagEndpoint):
         assert response.status_code == expected_status_code
         if expected_status_code == 200:
             body = response.json()
-            assert [dag["dag_id"] for dag in body["dags"]] == expected_ids
-            paused_dag_ids = [dag["dag_id"] for dag in body["dags"] if dag["is_paused"]]
-            assert paused_dag_ids == expected_paused_ids
+            assert {dag["dag_id"] for dag in body["dags"]} == set(expected_ids)
+            paused_dag_ids = {dag["dag_id"] for dag in body["dags"] if dag["is_paused"]}
+            assert paused_dag_ids == set(expected_paused_ids)
             check_last_log(session, dag_id=DAG1_ID, event="patch_dag", logical_date=None)
 
     @mock.patch("airflow.api_fastapi.auth.managers.base_auth_manager.BaseAuthManager.get_authorized_dag_ids")
@@ -371,7 +371,7 @@ class TestPatchDags(TestDagEndpoint):
         assert response.status_code == 200
         body = response.json()
 
-        assert [dag["dag_id"] for dag in body["dags"]] == [DAG1_ID, DAG2_ID]
+        assert {dag["dag_id"] for dag in body["dags"]} == {DAG1_ID, DAG2_ID}
 
     def test_patch_dags_should_response_401(self, unauthenticated_test_client):
         response = unauthenticated_test_client.patch("/dags", json={"is_paused": True})
@@ -386,15 +386,22 @@ class TestDagDetails(TestDagEndpoint):
     """Unit tests for DAG Details."""
 
     @pytest.mark.parametrize(
-        "query_params, dag_id, expected_status_code, dag_display_name, start_date",
+        "query_params, dag_id, expected_status_code, dag_display_name, start_date, owner_links",
         [
-            ({}, "fake_dag_id", 404, "fake_dag", "2023-12-31T00:00:00Z"),
-            ({}, DAG2_ID, 200, DAG2_ID, "2021-06-15T00:00:00Z"),
+            ({}, "fake_dag_id", 404, "fake_dag", "2023-12-31T00:00:00Z", {}),
+            ({}, DAG2_ID, 200, DAG2_ID, "2021-06-15T00:00:00Z", {}),
         ],
     )
     @pytest.mark.usefixtures("configure_git_connection_for_dag_bundle")
     def test_dag_details(
-        self, test_client, query_params, dag_id, expected_status_code, dag_display_name, start_date
+        self,
+        test_client,
+        query_params,
+        dag_id,
+        expected_status_code,
+        dag_display_name,
+        start_date,
+        owner_links,
     ):
         response = test_client.get(f"/dags/{dag_id}/details", params=query_params)
         assert response.status_code == expected_status_code
@@ -445,6 +452,7 @@ class TestDagDetails(TestDagEndpoint):
             "next_dagrun_logical_date": None,
             "next_dagrun_run_after": None,
             "owners": ["airflow"],
+            "owner_links": {},
             "params": {
                 "foo": {
                     "__class": "airflow.sdk.definitions.param.Param",
