@@ -44,6 +44,10 @@ TEST_VARIABLE_KEY3 = "dictionary_password"
 TEST_VARIABLE_VALUE3 = '{"password": "some_password"}'
 TEST_VARIABLE_DESCRIPTION3 = "Some description for the variable"
 
+TEST_VARIABLE_KEY4 = "test_variable_key/with_slashes"
+TEST_VARIABLE_VALUE4 = "test_variable_value"
+TEST_VARIABLE_DESCRIPTION4 = "Some description for the variable"
+
 
 TEST_VARIABLE_SEARCH_KEY = "test_variable_search_key"
 TEST_VARIABLE_SEARCH_VALUE = "random search value"
@@ -78,6 +82,13 @@ def _create_variables(session) -> None:
         session=session,
     )
 
+    Variable.set(
+        key=TEST_VARIABLE_KEY4,
+        value=TEST_VARIABLE_VALUE4,
+        description=TEST_VARIABLE_DESCRIPTION4,
+        session=session,
+    )
+
     Variable.set(
         key=TEST_VARIABLE_SEARCH_KEY,
         value=TEST_VARIABLE_SEARCH_VALUE,
@@ -102,9 +113,11 @@ class TestDeleteVariable(TestVariableEndpoint):
     def test_delete_should_respond_204(self, test_client, session):
         self.create_variables()
         variables = session.query(Variable).all()
-        assert len(variables) == 4
+        assert len(variables) == 5
         response = test_client.delete(f"/variables/{TEST_VARIABLE_KEY}")
         assert response.status_code == 204
+        response = test_client.delete(f"/variables/{TEST_VARIABLE_KEY4}")
+        assert response.status_code == 204
         variables = session.query(Variable).all()
         assert len(variables) == 3
         check_last_log(session, dag_id=None, event="delete_variable", logical_date=None)
@@ -156,6 +169,15 @@ class TestGetVariable(TestVariableEndpoint):
                     "is_encrypted": True,
                 },
             ),
+            (
+                TEST_VARIABLE_KEY4,
+                {
+                    "key": TEST_VARIABLE_KEY4,
+                    "value": TEST_VARIABLE_VALUE4,
+                    "description": TEST_VARIABLE_DESCRIPTION4,
+                    "is_encrypted": True,
+                },
+            ),
             (
                 TEST_VARIABLE_SEARCH_KEY,
                 {
@@ -194,35 +216,75 @@ class TestGetVariables(TestVariableEndpoint):
         "query_params, expected_total_entries, expected_keys",
         [
             # Filters
-            ({}, 4, [TEST_VARIABLE_KEY, TEST_VARIABLE_KEY2, TEST_VARIABLE_KEY3, TEST_VARIABLE_SEARCH_KEY]),
-            ({"limit": 1}, 4, [TEST_VARIABLE_KEY]),
-            ({"limit": 1, "offset": 1}, 4, [TEST_VARIABLE_KEY2]),
+            (
+                {},
+                5,
+                [
+                    TEST_VARIABLE_KEY,
+                    TEST_VARIABLE_KEY2,
+                    TEST_VARIABLE_KEY3,
+                    TEST_VARIABLE_KEY4,
+                    TEST_VARIABLE_SEARCH_KEY,
+                ],
+            ),
+            ({"limit": 1}, 5, [TEST_VARIABLE_KEY]),
+            ({"limit": 1, "offset": 1}, 5, [TEST_VARIABLE_KEY2]),
             # Sort
             (
                 {"order_by": "id"},
-                4,
-                [TEST_VARIABLE_KEY, TEST_VARIABLE_KEY2, TEST_VARIABLE_KEY3, TEST_VARIABLE_SEARCH_KEY],
+                5,
+                [
+                    TEST_VARIABLE_KEY,
+                    TEST_VARIABLE_KEY2,
+                    TEST_VARIABLE_KEY3,
+                    TEST_VARIABLE_KEY4,
+                    TEST_VARIABLE_SEARCH_KEY,
+                ],
             ),
             (
                 {"order_by": "-id"},
-                4,
-                [TEST_VARIABLE_SEARCH_KEY, TEST_VARIABLE_KEY3, TEST_VARIABLE_KEY2, TEST_VARIABLE_KEY],
+                5,
+                [
+                    TEST_VARIABLE_SEARCH_KEY,
+                    TEST_VARIABLE_KEY4,
+                    TEST_VARIABLE_KEY3,
+                    TEST_VARIABLE_KEY2,
+                    TEST_VARIABLE_KEY,
+                ],
             ),
             (
                 {"order_by": "key"},
-                4,
-                [TEST_VARIABLE_KEY3, TEST_VARIABLE_KEY2, TEST_VARIABLE_KEY, TEST_VARIABLE_SEARCH_KEY],
+                5,
+                [
+                    TEST_VARIABLE_KEY3,
+                    TEST_VARIABLE_KEY2,
+                    TEST_VARIABLE_KEY,
+                    TEST_VARIABLE_KEY4,
+                    TEST_VARIABLE_SEARCH_KEY,
+                ],
             ),
             (
                 {"order_by": "-key"},
-                4,
-                [TEST_VARIABLE_SEARCH_KEY, TEST_VARIABLE_KEY, TEST_VARIABLE_KEY2, TEST_VARIABLE_KEY3],
+                5,
+                [
+                    TEST_VARIABLE_SEARCH_KEY,
+                    TEST_VARIABLE_KEY4,
+                    TEST_VARIABLE_KEY,
+                    TEST_VARIABLE_KEY2,
+                    TEST_VARIABLE_KEY3,
+                ],
             ),
             # Search
             (
                 {"variable_key_pattern": "~"},
-                4,
-                [TEST_VARIABLE_KEY, TEST_VARIABLE_KEY2, TEST_VARIABLE_KEY3, TEST_VARIABLE_SEARCH_KEY],
+                5,
+                [
+                    TEST_VARIABLE_KEY,
+                    TEST_VARIABLE_KEY2,
+                    TEST_VARIABLE_KEY3,
+                    TEST_VARIABLE_KEY4,
+                    TEST_VARIABLE_SEARCH_KEY,
+                ],
             ),
             ({"variable_key_pattern": "search"}, 1, [TEST_VARIABLE_SEARCH_KEY]),
         ],
@@ -282,6 +344,21 @@ class TestPatchVariable(TestVariableEndpoint):
                     "is_encrypted": True,
                 },
             ),
+            (
+                TEST_VARIABLE_KEY4,
+                {
+                    "key": TEST_VARIABLE_KEY4,
+                    "value": "The new value",
+                    "description": "The new description",
+                },
+                {"update_mask": ["value"]},
+                {
+                    "key": TEST_VARIABLE_KEY4,
+                    "value": "The new value",
+                    "description": TEST_VARIABLE_DESCRIPTION4,
+                    "is_encrypted": True,
+                },
+            ),
             (
                 TEST_VARIABLE_KEY2,
                 {
@@ -983,6 +1060,55 @@ class TestBulkVariables(TestVariableEndpoint):
             assert response_data[key] == value
         check_last_log(session, dag_id=None, event="bulk_variables", logical_date=None)
 
+    @pytest.mark.parametrize(
+        "entity_key, entity_value, entity_description",
+        [
+            (
+                "my_dict_var_param",
+                {"name": "Test Dict Param", "id": 123, "active": True},
+                "A dict value (param)",
+            ),
+            ("my_list_var_param", ["alpha", 42, False, {"nested": "item param"}], "A list value (param)"),
+            ("my_string_var_param", "plain string param", "A plain string (param)"),
+        ],
+        ids=[
+            "dict_variable",
+            "list_variable",
+            "string_variable",
+        ],
+    )
+    def test_bulk_create_entity_serialization(
+        self, test_client, session, entity_key, entity_value, entity_description
+    ):
+        actions = {
+            "actions": [
+                {
+                    "action": "create",
+                    "entities": [
+                        {"key": entity_key, "value": entity_value, "description": entity_description},
+                    ],
+                    "action_on_existence": "fail",
+                }
+            ]
+        }
+
+        response = test_client.patch("/variables", json=actions)
+        assert response.status_code == 200
+
+        if isinstance(entity_value, (dict, list)):
+            retrieved_value_deserialized = Variable.get(entity_key, deserialize_json=True)
+            assert retrieved_value_deserialized == entity_value
+            retrieved_value_raw_string = Variable.get(entity_key, deserialize_json=False)
+            assert retrieved_value_raw_string == json.dumps(entity_value, indent=2)
+        else:
+            retrieved_value_raw = Variable.get(entity_key, deserialize_json=False)
+            assert retrieved_value_raw == str(entity_value)
+
+            with pytest.raises(json.JSONDecodeError):
+                Variable.get(entity_key, deserialize_json=True)
+
+        check_last_log(session, dag_id=None, event="bulk_variables", logical_date=None)
+
     def test_bulk_variables_should_respond_401(self, unauthenticated_test_client):
         response = unauthenticated_test_client.patch("/variables", json={})
         assert response.status_code == 401
