@@ -35,7 +35,7 @@ from airflow.models.taskinstancehistory import TaskInstanceHistory
 from airflow.providers.standard.operators.empty import EmptyOperator
 from airflow.sdk import Asset, TaskGroup, task, task_group
 from airflow.utils import timezone
-from airflow.utils.state import State, TaskInstanceState, TerminalTIState
+from airflow.utils.state import DagRunState, State, TaskInstanceState, TerminalTIState
 
 from tests_common.test_utils.db import (
     clear_db_assets,
@@ -155,6 +155,7 @@ class TestTIRunState:
         ti = create_task_instance(
             task_id="test_ti_run_state_to_running",
             state=State.QUEUED,
+            dagrun_state=DagRunState.RUNNING,
             session=session,
             start_date=instant,
             dag_id=str(uuid4()),
@@ -184,6 +185,7 @@ class TestTIRunState:
                 "data_interval_end": instant_str,
                 "run_after": instant_str,
                 "start_date": instant_str,
+                "state": "running",
                 "end_date": None,
                 "run_type": "manual",
                 "conf": {},
@@ -299,6 +301,81 @@ class TestTIRunState:
             upstream_map_indexes = response.json()["upstream_map_indexes"]
             assert upstream_map_indexes == expected_upstream_map_indexes[(ti.task_id, ti.map_index)]
 
+    def test_nested_mapped_task_group_upstream_indexes(self, client, dag_maker):
+        """
+        Test that upstream_map_indexes are correctly computed for tasks in nested mapped task groups.
+        """
+        with dag_maker("test_nested_mapped_tg", serialized=True):
+
+            @task
+            def alter_input(inp: str) -> str:
+                return f"{inp}_Altered"
+
+            @task
+            def print_task(orig_input: str, altered_input: str) -> str:
+                return f"orig:{orig_input},altered:{altered_input}"
+
+            @task_group
+            def inner_task_group(orig_input: str) -> None:
+                altered_input = alter_input(orig_input)
+                print_task(orig_input, altered_input)
+
+            @task_group
+            def expandable_task_group(param: str) -> None:
+                inner_task_group(param)
+
+            expandable_task_group.expand(param=["One", "Two", "Three"])
+
+        dr = dag_maker.create_dagrun()
+
+        # Set all alter_input tasks to success so print_task can run
+        for ti in dr.get_task_instances():
+            if "alter_input" in ti.task_id and ti.map_index >= 0:
+                ti.state = State.SUCCESS
+            elif "print_task" in ti.task_id and ti.map_index >= 0:
+                ti.set_state(State.QUEUED)
+        dag_maker.session.flush()
+
+        # Expected upstream_map_indexes for each print_task instance
+        expected_upstream_map_indexes = {
+            ("expandable_task_group.inner_task_group.print_task", 0): {
+                "expandable_task_group.inner_task_group.alter_input": 0
+            },
+            ("expandable_task_group.inner_task_group.print_task", 1): {
+                "expandable_task_group.inner_task_group.alter_input": 1
+            },
+            ("expandable_task_group.inner_task_group.print_task", 2): {
+                "expandable_task_group.inner_task_group.alter_input": 2
+            },
+        }
+
+        # Get only the expanded print_task instances (not the template)
+        print_task_tis = [
+            ti for ti in dr.get_task_instances() if "print_task" in ti.task_id and ti.map_index >= 0
+        ]
+
+        # Test each print_task instance
+        for ti in print_task_tis:
+            response = client.patch(
+                f"/execution/task-instances/{ti.id}/run",
+                json={
+                    "state": "running",
+                    "hostname": "random-hostname",
+                    "unixname": "random-unixname",
+                    "pid": 100,
+                    "start_date": "2024-09-30T12:00:00Z",
+                },
+            )
+
+            assert response.status_code == 200
+            upstream_map_indexes = response.json()["upstream_map_indexes"]
+            expected = expected_upstream_map_indexes[(ti.task_id, ti.map_index)]
+
+            assert upstream_map_indexes == expected, (
+                f"Task {ti.task_id}[{ti.map_index}] should have upstream_map_indexes {expected}, "
+                f"but got {upstream_map_indexes}"
+            )
+
     def test_dynamic_task_mapping_with_xcom(self, client, dag_maker, create_task_instance, session, run_task):
         """
         Test that the Task Instance upstream_map_indexes is correctly fetched when to running the Task Instances with xcom
@@ -1909,7 +1986,7 @@ class TestGetTaskStates:
             },
         }
 
-    def test_get_task_group_states_with_logical_dates(self, client, session, dag_maker, serialized=True):
+    def test_get_task_group_states_with_logical_dates(self, client, session, dag_maker):
         with dag_maker("test_get_task_group_states_with_logical_dates", serialized=True):
             with TaskGroup("group1"):
                 EmptyOperator(task_id="task1")
