@@ -31,6 +31,7 @@ from airflow.models.taskmap import TaskMap
 from airflow.models.xcom import XComModel
 from airflow.providers.standard.operators.empty import EmptyOperator
 from airflow.serialization.serde import deserialize, serialize
+from airflow.utils import timezone
 from airflow.utils.session import create_session
 
 pytestmark = pytest.mark.db_test
@@ -273,6 +274,54 @@ class TestXComsGetEndpoint:
         assert response.status_code == 200
         assert response.json() == ["f", "o", "b"][key]
 
+    @pytest.mark.parametrize(
+        "include_prior_dates, expected_xcoms",
+        [[True, ["earlier_value", "later_value"]], [False, ["later_value"]]],
+    )
+    def test_xcom_get_slice_accepts_include_prior_dates(
+        self, client, dag_maker, session, include_prior_dates, expected_xcoms
+    ):
+        """Test that the slice endpoint accepts include_prior_dates parameter and works correctly."""
+
+        with dag_maker(dag_id="dag"):
+            EmptyOperator(task_id="task")
+
+        earlier_run = dag_maker.create_dagrun(
+            run_id="earlier_run", logical_date=timezone.parse("2024-01-01T00:00:00Z")
+        )
+        later_run = dag_maker.create_dagrun(
+            run_id="later_run", logical_date=timezone.parse("2024-01-02T00:00:00Z")
+        )
+
+        earlier_ti = earlier_run.get_task_instance("task")
+        later_ti = later_run.get_task_instance("task")
+
+        earlier_xcom = XComModel(
+            key="test_key",
+            value="earlier_value",
+            dag_run_id=earlier_ti.dag_run.id,
+            run_id=earlier_ti.run_id,
+            task_id=earlier_ti.task_id,
+            dag_id=earlier_ti.dag_id,
+        )
+        later_xcom = XComModel(
+            key="test_key",
+            value="later_value",
+            dag_run_id=later_ti.dag_run.id,
+            run_id=later_ti.run_id,
+            task_id=later_ti.task_id,
+            dag_id=later_ti.dag_id,
+        )
+        session.add_all([earlier_xcom, later_xcom])
+        session.commit()
+
+        response = client.get(
+            f"/execution/xcoms/dag/later_run/task/test_key/slice?include_prior_dates={include_prior_dates}"
+        )
+        assert response.status_code == 200
+
+        assert set(response.json()) == set(expected_xcoms)
+
 
 class TestXComsSetEndpoint:
     @pytest.mark.parametrize(
