@@ -520,7 +520,9 @@ class TestDagFileProcessorManager:
 
     def test_kill_timed_out_processors_kill(self):
         manager = DagFileProcessorManager(max_runs=1, processor_timeout=5)
-        processor, _ = self.mock_processor(start_time=16000)
+        # Set start_time to ensure timeout occurs: start_time = current_time - (timeout + 1) = always (timeout + 1) seconds
+        start_time = time.monotonic() - manager.processor_timeout - 1
+        processor, _ = self.mock_processor(start_time=start_time)
         manager._processors = {
             DagFileInfo(
                 bundle_name="testing", rel_path=Path("abc.txt"), bundle_path=TEST_DAGS_FOLDER
@@ -571,6 +573,7 @@ class TestDagFileProcessorManager:
                         run_id="run_id",
                         bundle_name="testing",
                         bundle_version=None,
+                        context_from_server=None,
                         is_failure_callback=False,
                     )
                 ],
@@ -586,6 +589,7 @@ class TestDagFileProcessorManager:
                             "msg": None,
                             "dag_id": "dag_id",
                             "run_id": "run_id",
+                            "context_from_server": None,
                             "is_failure_callback": False,
                             "type": "DagCallbackRequest",
                         }
