@@ -32,7 +32,6 @@ from airflow.models.taskinstance import TaskInstance
 from airflow.models.taskmap import TaskMap
 from airflow.providers.standard.operators.python import PythonOperator
 from airflow.sdk import setup, task, task_group, teardown
-from airflow.sdk.execution_time.comms import XComCountResponse, XComResult
 from airflow.utils.state import TaskInstanceState
 from airflow.utils.task_group import TaskGroup
 from airflow.utils.trigger_rule import TriggerRule
@@ -397,11 +396,16 @@ def test_expand_mapped_task_instance_with_named_index(
     expected_rendered_names,
 ) -> None:
     """Test that the correct number of downstream tasks are generated when mapping with an XComArg"""
-    with dag_maker("test-dag", session=session, start_date=DEFAULT_DATE):
+    dag_id = "test_dag_12345"
+    with dag_maker(
+        dag_id=dag_id,
+        start_date=DEFAULT_DATE,
+        serialized=True,
+    ):
         create_mapped_task(task_id="task1", map_names=["a", "b"], template=template)
 
-    dr = dag_maker.create_dagrun()
-    tis = dr.get_task_instances()
+    dr = dag_maker.create_dagrun(session=session)
+    tis = dr.get_task_instances(session=session)
     for ti in tis:
         ti.run()
     session.flush()
@@ -409,7 +413,7 @@ def test_expand_mapped_task_instance_with_named_index(
     indices = session.scalars(
         select(TaskInstance.rendered_map_index)
         .where(
-            TaskInstance.dag_id == "test-dag",
+            TaskInstance.dag_id == dag_id,
             TaskInstance.task_id == "task1",
             TaskInstance.run_id == dr.run_id,
         )
@@ -1265,21 +1269,7 @@ class TestMappedSetupTeardown:
         tg1, tg2 = dag.task_group.children.values()
         tg1 >> tg2
 
-        with mock.patch(
-            "airflow.sdk.execution_time.task_runner.SUPERVISOR_COMMS", create=True
-        ) as supervisor_comms:
-            # TODO: TaskSDK: this is a bit of a hack that we need to stub this at all. `dag.test()` should
-            # really work without this!
-            supervisor_comms.get_message.side_effect = [
-                XComCountResponse(len=3),
-                XComResult(key="return_value", value=1),
-                XComCountResponse(len=3),
-                XComResult(key="return_value", value=2),
-                XComCountResponse(len=3),
-                XComResult(key="return_value", value=3),
-            ]
-            dr = dag.test()
-            assert supervisor_comms.get_message.call_count == 6
+        dr = dag.test()
         states = self.get_states(dr)
         expected = {
             "tg_1.my_pre_setup": "success",
