@@ -55,7 +55,7 @@ from airflow.sdk.definitions._internal.abstractoperator import (
 )
 from airflow.sdk.definitions._internal.decorators import fixup_decorator_warning_stack
 from airflow.sdk.definitions._internal.node import validate_key
-from airflow.sdk.definitions._internal.types import NOTSET, ArgNotSet, validate_instance_args
+from airflow.sdk.definitions._internal.types import NOTSET, validate_instance_args
 from airflow.sdk.definitions.edges import EdgeModifier
 from airflow.sdk.definitions.mappedoperator import OperatorPartial, validate_mapping_kwargs
 from airflow.sdk.definitions.param import ParamsDict
@@ -232,63 +232,48 @@ if TYPE_CHECKING:
         task_id: str,
         dag: DAG | None = None,
         task_group: TaskGroup | None = None,
-        start_date: datetime | ArgNotSet = NOTSET,
-        end_date: datetime | ArgNotSet = NOTSET,
-        owner: str | ArgNotSet = NOTSET,
-        email: None | str | Iterable[str] | ArgNotSet = NOTSET,
+        start_date: datetime = ...,
+        end_date: datetime = ...,
+        owner: str = ...,
+        email: None | str | Iterable[str] = ...,
         params: collections.abc.MutableMapping | None = None,
-        resources: dict[str, Any] | None | ArgNotSet = NOTSET,
-        trigger_rule: str | ArgNotSet = NOTSET,
-        depends_on_past: bool | ArgNotSet = NOTSET,
-        ignore_first_depends_on_past: bool | ArgNotSet = NOTSET,
-        wait_for_past_depends_before_skipping: bool | ArgNotSet = NOTSET,
-        wait_for_downstream: bool | ArgNotSet = NOTSET,
-        retries: int | None | ArgNotSet = NOTSET,
-        queue: str | ArgNotSet = NOTSET,
-        pool: str | ArgNotSet = NOTSET,
-        pool_slots: int | ArgNotSet = NOTSET,
-        execution_timeout: timedelta | None | ArgNotSet = NOTSET,
-        max_retry_delay: None | timedelta | float | ArgNotSet = NOTSET,
-        retry_delay: timedelta | float | ArgNotSet = NOTSET,
-        retry_exponential_backoff: bool | ArgNotSet = NOTSET,
-        priority_weight: int | ArgNotSet = NOTSET,
-        weight_rule: str | PriorityWeightStrategy | ArgNotSet = NOTSET,
-        sla: timedelta | None | ArgNotSet = NOTSET,
-        map_index_template: str | None | ArgNotSet = NOTSET,
-        max_active_tis_per_dag: int | None | ArgNotSet = NOTSET,
-        max_active_tis_per_dagrun: int | None | ArgNotSet = NOTSET,
-        on_execute_callback: None
-        | TaskStateChangeCallback
-        | list[TaskStateChangeCallback]
-        | ArgNotSet = NOTSET,
-        on_failure_callback: None
-        | TaskStateChangeCallback
-        | list[TaskStateChangeCallback]
-        | ArgNotSet = NOTSET,
-        on_success_callback: None
-        | TaskStateChangeCallback
-        | list[TaskStateChangeCallback]
-        | ArgNotSet = NOTSET,
-        on_retry_callback: None
-        | TaskStateChangeCallback
-        | list[TaskStateChangeCallback]
-        | ArgNotSet = NOTSET,
-        on_skipped_callback: None
-        | TaskStateChangeCallback
-        | list[TaskStateChangeCallback]
-        | ArgNotSet = NOTSET,
-        run_as_user: str | None | ArgNotSet = NOTSET,
-        executor: str | None | ArgNotSet = NOTSET,
-        executor_config: dict | None | ArgNotSet = NOTSET,
-        inlets: Any | None | ArgNotSet = NOTSET,
-        outlets: Any | None | ArgNotSet = NOTSET,
-        doc: str | None | ArgNotSet = NOTSET,
-        doc_md: str | None | ArgNotSet = NOTSET,
-        doc_json: str | None | ArgNotSet = NOTSET,
-        doc_yaml: str | None | ArgNotSet = NOTSET,
-        doc_rst: str | None | ArgNotSet = NOTSET,
-        task_display_name: str | None | ArgNotSet = NOTSET,
-        logger_name: str | None | ArgNotSet = NOTSET,
+        resources: dict[str, Any] | None = ...,
+        trigger_rule: str = ...,
+        depends_on_past: bool = ...,
+        ignore_first_depends_on_past: bool = ...,
+        wait_for_past_depends_before_skipping: bool = ...,
+        wait_for_downstream: bool = ...,
+        retries: int | None = ...,
+        queue: str = ...,
+        pool: str = ...,
+        pool_slots: int = ...,
+        execution_timeout: timedelta | None = ...,
+        max_retry_delay: None | timedelta | float = ...,
+        retry_delay: timedelta | float = ...,
+        retry_exponential_backoff: bool = ...,
+        priority_weight: int = ...,
+        weight_rule: str | PriorityWeightStrategy = ...,
+        sla: timedelta | None = ...,
+        map_index_template: str | None = ...,
+        max_active_tis_per_dag: int | None = ...,
+        max_active_tis_per_dagrun: int | None = ...,
+        on_execute_callback: None | TaskStateChangeCallback | list[TaskStateChangeCallback] = ...,
+        on_failure_callback: None | TaskStateChangeCallback | list[TaskStateChangeCallback] = ...,
+        on_success_callback: None | TaskStateChangeCallback | list[TaskStateChangeCallback] = ...,
+        on_retry_callback: None | TaskStateChangeCallback | list[TaskStateChangeCallback] = ...,
+        on_skipped_callback: None | TaskStateChangeCallback | list[TaskStateChangeCallback] = ...,
+        run_as_user: str | None = ...,
+        executor: str | None = ...,
+        executor_config: dict | None = ...,
+        inlets: Any | None = ...,
+        outlets: Any | None = ...,
+        doc: str | None = ...,
+        doc_md: str | None = ...,
+        doc_json: str | None = ...,
+        doc_yaml: str | None = ...,
+        doc_rst: str | None = ...,
+        task_display_name: str | None = ...,
+        logger_name: str | None = ...,
         allow_nested_operators: bool = True,
         **kwargs,
     ) -> OperatorPartial: ...
@@ -330,8 +315,12 @@ else:
         }
 
         # Inject DAG-level default args into args provided to this function.
+        # Most of the default args will be retrieved during unmapping; here we
+        # only ensure base properties are correctly set for the scheduler.
         partial_kwargs.update(
-            (k, v) for k, v in dag_default_args.items() if partial_kwargs.get(k, NOTSET) is NOTSET
+            (k, v)
+            for k, v in dag_default_args.items()
+            if k not in partial_kwargs and k in BaseOperator.__init__._BaseOperatorMeta__param_names
         )
 
         # Fill fields not provided by the user with default values.
@@ -793,8 +782,8 @@ class BaseOperator(AbstractOperator, metaclass=BaseOperatorMeta):
     :param task_display_name: The display name of the task which appears on the UI.
     :param logger_name: Name of the logger used by the Operator to emit logs.
         If set to `None` (default), the logger name will fall back to
-        `airflow.task.operators.{class.__module__}.{class.__name__}` (e.g. SimpleHttpOperator will have
-        *airflow.task.operators.airflow.providers.http.operators.http.SimpleHttpOperator* as logger).
+        `airflow.task.operators.{class.__module__}.{class.__name__}` (e.g. HttpOperator will have
+        *airflow.task.operators.airflow.providers.http.operators.http.HttpOperator* as logger).
     :param allow_nested_operators: if True, when an operator is executed within another one a warning message
         will be logged. If False, then an exception will be raised if the operator is badly used (e.g. nested
         within another one). In future releases of Airflow this parameter will be removed and an exception
@@ -1025,9 +1014,13 @@ class BaseOperator(AbstractOperator, metaclass=BaseOperatorMeta):
     ):
         # Note: Metaclass handles passing in the DAG/TaskGroup from active context manager, if any
 
-        self.task_id = task_group.child_id(task_id) if task_group else task_id
-        if not self.__from_mapped and task_group:
+        # Only apply task_group prefix if this operator was not created from a mapped operator
+        # Mapped operators already have the prefix applied during their creation
+        if task_group and not self.__from_mapped:
+            self.task_id = task_group.child_id(task_id)
             task_group.add(self)
+        else:
+            self.task_id = task_id
 
         super().__init__()
         self.task_group = task_group
@@ -1083,13 +1076,6 @@ class BaseOperator(AbstractOperator, metaclass=BaseOperatorMeta):
 
         if end_date:
             self.end_date = timezone.convert_to_utc(end_date)
-
-        if executor:
-            warnings.warn(
-                "Specifying executors for operators is not yet supported, the value {executor!r} will have no effect",
-                category=UserWarning,
-                stacklevel=2,
-            )
         self.executor = executor
         self.executor_config = executor_config or {}
         self.run_as_user = run_as_user
