@@ -190,7 +190,7 @@ class TestConnectionAccessor:
         # Conn from the supervisor / API Server
         conn_result = ConnectionResult(conn_id="mysql_conn", conn_type="mysql", host="mysql", port=3306)
 
-        mock_supervisor_comms.get_message.return_value = conn_result
+        mock_supervisor_comms.send.return_value = conn_result
 
         # Fetch the connection; triggers __getattr__
         conn = accessor.mysql_conn
@@ -203,7 +203,7 @@ class TestConnectionAccessor:
         accessor = ConnectionAccessor()
         conn_result = ConnectionResult(conn_id="mysql_conn", conn_type="mysql", host="mysql", port=3306)
 
-        mock_supervisor_comms.get_message.return_value = conn_result
+        mock_supervisor_comms.send.return_value = conn_result
 
         conn = accessor.get("mysql_conn")
         assert conn == Connection(conn_id="mysql_conn", conn_type="mysql", host="mysql", port=3306)
@@ -216,7 +216,7 @@ class TestConnectionAccessor:
             error=ErrorType.CONNECTION_NOT_FOUND, detail={"conn_id": "nonexistent_conn"}
         )
 
-        mock_supervisor_comms.get_message.return_value = error_response
+        mock_supervisor_comms.send.return_value = error_response
 
         conn = accessor.get("nonexistent_conn", default_conn=default_conn)
         assert conn == default_conn
@@ -233,7 +233,7 @@ class TestConnectionAccessor:
             extra='{"extra_key": "extra_value"}',
         )
 
-        mock_supervisor_comms.get_message.return_value = conn_result
+        mock_supervisor_comms.send.return_value = conn_result
 
         # Fetch the connection's dejson; triggers __getattr__
         dejson = accessor.mysql_conn.extra_dejson
@@ -251,7 +251,7 @@ class TestConnectionAccessor:
             conn_id="mysql_conn", conn_type="mysql", host="mysql", port=3306, extra="This is not JSON!"
         )
 
-        mock_supervisor_comms.get_message.return_value = conn_result
+        mock_supervisor_comms.send.return_value = conn_result
 
         # Fetch the connection's dejson; triggers __getattr__
         dejson = accessor.mysql_conn.extra_dejson
@@ -274,7 +274,7 @@ class TestVariableAccessor:
         # Variable from the supervisor / API Server
         var_result = VariableResult(key="test_key", value="test_value")
 
-        mock_supervisor_comms.get_message.return_value = var_result
+        mock_supervisor_comms.send.return_value = var_result
 
         # Fetch the variable; triggers __getattr__
         value = accessor.test_key
@@ -286,7 +286,7 @@ class TestVariableAccessor:
         accessor = VariableAccessor(deserialize_json=False)
         var_result = VariableResult(key="test_key", value="test_value")
 
-        mock_supervisor_comms.get_message.return_value = var_result
+        mock_supervisor_comms.send.return_value = var_result
 
         val = accessor.get("test_key")
         assert val == var_result.value
@@ -297,7 +297,7 @@ class TestVariableAccessor:
         accessor = VariableAccessor(deserialize_json=False)
         error_response = ErrorResponse(error=ErrorType.VARIABLE_NOT_FOUND, detail={"test_key": "test_value"})
 
-        mock_supervisor_comms.get_message.return_value = error_response
+        mock_supervisor_comms.send.return_value = error_response
 
         val = accessor.get("nonexistent_var_key", default="default_value")
         assert val == "default_value"
@@ -367,7 +367,7 @@ class TestOutletEventAccessor:
         ),
     )
     def test_add(self, add_arg, key, asset_alias_events, mock_supervisor_comms):
-        mock_supervisor_comms.get_message.return_value = AssetResponse(name="name", uri="uri", group="")
+        mock_supervisor_comms.send.return_value = AssetResponse(name="name", uri="uri", group="")
 
         outlet_event_accessor = OutletEventAccessor(key=key, extra={})
         outlet_event_accessor.add(add_arg)
@@ -398,7 +398,7 @@ class TestOutletEventAccessor:
         ),
     )
     def test_add_with_db(self, add_arg, key, asset_alias_events, mock_supervisor_comms):
-        mock_supervisor_comms.get_message.return_value = AssetResponse(name="name", uri="uri", group="")
+        mock_supervisor_comms.send.return_value = AssetResponse(name="name", uri="uri", group="")
 
         outlet_event_accessor = OutletEventAccessor(key=key, extra={"not": ""})
         outlet_event_accessor.add(add_arg, extra={})
@@ -497,11 +497,11 @@ class TestTriggeringAssetEventsAccessor:
         resolved_asset,
         result_indexes,
     ):
-        mock_supervisor_comms.get_message.return_value = resolved_asset
+        mock_supervisor_comms.send.return_value = resolved_asset
         expected = [AssetEventDagRunReferenceResult.model_validate(event_data[i]) for i in result_indexes]
         assert accessor[Asset.ref(name=name)] == expected
-        assert len(mock_supervisor_comms.send_request.mock_calls) == 1
-        assert mock_supervisor_comms.send_request.mock_calls[0].kwargs["msg"] == GetAssetByName(name=name)
+
+        mock_supervisor_comms.send.assert_called_once_with(GetAssetByName(name=name, type="GetAssetByName"))
         assert _AssetRefResolutionMixin._asset_ref_cache
 
     @pytest.mark.parametrize(
@@ -520,11 +520,10 @@ class TestTriggeringAssetEventsAccessor:
         resolved_asset,
         result_indexes,
     ):
-        mock_supervisor_comms.get_message.return_value = resolved_asset
+        mock_supervisor_comms.send.return_value = resolved_asset
         expected = [AssetEventDagRunReferenceResult.model_validate(event_data[i]) for i in result_indexes]
         assert accessor[Asset.ref(uri=uri)] == expected
-        assert len(mock_supervisor_comms.send_request.mock_calls) == 1
-        assert mock_supervisor_comms.send_request.mock_calls[0].kwargs["msg"] == GetAssetByUri(uri=uri)
+        mock_supervisor_comms.send.assert_called_once_with(GetAssetByUri(uri=uri))
         assert _AssetRefResolutionMixin._asset_ref_cache
 
     def test_source_task_instance_xcom_pull(self, mock_supervisor_comms, accessor):
@@ -534,22 +533,19 @@ class TestTriggeringAssetEventsAccessor:
         assert source == AssetEventSourceTaskInstance(dag_id="d1", task_id="t2", run_id="r1", map_index=-1)
 
         mock_supervisor_comms.reset_mock()
-        mock_supervisor_comms.get_message.side_effect = [
+        mock_supervisor_comms.send.side_effect = [
             XComResult(key="return_value", value="__example_xcom_value__"),
         ]
         assert source.xcom_pull() == "__example_xcom_value__"
-        assert mock_supervisor_comms.send_request.mock_calls == [
-            mock.call(
-                log=mock.ANY,
-                msg=GetXCom(
-                    key="return_value",
-                    dag_id="d1",
-                    run_id="r1",
-                    task_id="t2",
-                    map_index=-1,
-                ),
+        mock_supervisor_comms.send.assert_called_once_with(
+            msg=GetXCom(
+                key="return_value",
+                dag_id="d1",
+                run_id="r1",
+                task_id="t2",
+                map_index=-1,
             ),
-        ]
+        )
 
 
 TEST_ASSET = Asset(name="test_uri", uri="test://test")
@@ -593,7 +589,7 @@ class TestOutletEventAccessors:
         assert len(outlet_event_accessors) == 0
 
         # Asset from the API Server via the supervisor
-        mock_supervisor_comms.get_message.return_value = AssetResult(
+        mock_supervisor_comms.send.return_value = AssetResult(
             name=asset.name,
             uri=asset.uri,
             group=asset.group,
@@ -628,7 +624,7 @@ class TestOutletEventAccessors:
 class TestInletEventAccessor:
     @pytest.fixture
     def sample_inlet_evnets_accessor(self, mock_supervisor_comms):
-        mock_supervisor_comms.get_message.side_effect = [
+        mock_supervisor_comms.send.side_effect = [
             AssetResult(name="test_uri", uri="test://test", group="asset"),
             AssetResult(name="test_uri", uri="test://test", group="asset"),
         ]
@@ -656,7 +652,7 @@ class TestInletEventAccessor:
             asset=AssetResponse(name="test", uri="test", group="asset"),
         )
         events_result = AssetEventsResult(asset_events=[asset_event_resp])
-        mock_supervisor_comms.get_message.side_effect = [events_result] * 4
+        mock_supervisor_comms.send.side_effect = [events_result] * 4
 
         assert sample_inlet_evnets_accessor[key] == [asset_event_resp]
 
@@ -684,7 +680,7 @@ class TestInletEventAccessor:
         assert mocked__getitem__.call_args[0][0] == TEST_ASSET_ALIAS
 
     def test_source_task_instance_xcom_pull(self, sample_inlet_evnets_accessor, mock_supervisor_comms):
-        mock_supervisor_comms.get_message.side_effect = [
+        mock_supervisor_comms.send.side_effect = [
             AssetEventsResult(
                 asset_events=[
                     AssetEventResponse(
@@ -707,9 +703,7 @@ class TestInletEventAccessor:
             )
         ]
         events = sample_inlet_evnets_accessor[Asset.ref(name="test_uri")]
-        assert mock_supervisor_comms.send_request.mock_calls == [
-            mock.call(log=mock.ANY, msg=GetAssetEventByAsset(name="test_uri", uri=None)),
-        ]
+        mock_supervisor_comms.send.assert_called_once_with(GetAssetEventByAsset(name="test_uri", uri=None))
 
         assert len(events) == 2
         assert events[1].source_task_instance is None
@@ -723,19 +717,16 @@ class TestInletEventAccessor:
         )
 
         mock_supervisor_comms.reset_mock()
-        mock_supervisor_comms.get_message.side_effect = [
+        mock_supervisor_comms.send.side_effect = [
             XComResult(key="return_value", value="__example_xcom_value__"),
         ]
         assert source.xcom_pull() == "__example_xcom_value__"
-        assert mock_supervisor_comms.send_request.mock_calls == [
-            mock.call(
-                log=mock.ANY,
-                msg=GetXCom(
-                    key="return_value",
-                    dag_id="__dag__",
-                    run_id="__run__",
-                    task_id="__task__",
-                    map_index=0,
-                ),
+        mock_supervisor_comms.send.assert_called_once_with(
+            msg=GetXCom(
+                key="return_value",
+                dag_id="__dag__",
+                run_id="__run__",
+                task_id="__task__",
+                map_index=0,
             ),
-        ]
+        )
